@@ -40,57 +40,69 @@ import copy
 
 # %%
 class hgboost:
-    """Create a class hgboost that is instantiated with the desired method."""
+    """hgboost: Hyperoptimized Gradient Boosting.
+
+    Description
+    -----------
+    HGBoost stands for Hyperoptimized Gradient Boosting and is a Python package for hyperparameter optimization
+    for XGBoost, LightBoost, and CatBoost. It will carefully split the dataset into a train, test, and independent
+    validation set. Within the train-test set, there is the inner loop for optimizing the hyperparameters using
+    Bayesian optimization (with hyperopt) and, the outer loop to score how well the top performing models can
+    generalize based on k-fold cross validation. As such, it will make the best attempt to select the most robust
+    model with the best performance.
+
+    Parameters
+    ----------
+    max_eval : int, (default : 250)
+        Search space is created on the number of evaluations.
+    threshold : float, (default : 0.5)
+        Classification threshold. In case of two-class model this is 0.5
+    cv : int, optional (default : 5)
+        Cross-validation. Specifying the test size by test_size.
+    top_cv_evals : int, (default : 10)
+        Number of top best performing models that is evaluated.
+        If set to None, each iteration (max_eval) is tested.
+        If set to 0, cross validation is not performed.
+    test_size : float, (default : 0.2)
+        Percentage split for the testset based on the total dataset.
+    val_size : float, (default : 0.2)
+        Percentage split for the validationset based on the total dataset. This part is kept untouched, and used only once to determine the model performance.
+    is_unbalance : Bool, (default: True)
+        Control the balance of positive and negative weights, useful for unbalanced classes.
+        xgboost clf : sum(negative instances) / sum(positive instances)
+        catboost clf : sum(negative instances) / sum(positive instances)
+        lightgbm clf : balanced
+        False: grid search
+    random_state : int, (default : None)
+        Fix the random state for validation set and test set. Note that is not used for the crossvalidation.
+    n_jobs : int, (default : -1)
+        The number of jobs to run in parallel for fit. None means 1 unless in a joblib.parallel_backend context.
+        -1 means using all processors.
+    gpu : bool, (default : False)
+        Computing using either GPU or CPU. Note that GPU usage is not very well supported because various optimizations are performed during training/testing/crossvalidation.
+        True: Use GPU.
+        False: Use CPU.
+    verbose : int, (default : 3)
+        Print progress to screen.
+        0: None, 1: ERROR, 2: WARN, 3: INFO, 4: DEBUG, 5: TRACE
+
+    Returns
+    -------
+    None.
+
+    References
+    ----------
+    * Blog: https://towardsdatascience.com/a-guide-to-find-the-best-boosting-model-using-bayesian-hyperparameter-tuning-but-without-c98b6a1ecac8
+    * Blog - classifiction: https://erdogant.medium.com/hands-on-guide-for-hyperparameter-tuning-with-bayesian-optimization-for-classification-models-2002224bfa3d
+    * Github : https://github.com/erdogant/hgboost
+    * Documentation pages: https://erdogant.github.io/hgboost/
+    * Notebook Classification: https://colab.research.google.com/github/erdogant/hgboost/blob/master/notebooks/hgboost_classification_examples.ipynb
+    * Notebook Regression: https://colab.research.google.com/github/erdogant/hgboost/blob/master/notebooks/hgboost_regression_examples.ipynb
+
+    """
 
     def __init__(self, max_eval=250, threshold=0.5, cv=5, test_size=0.2, val_size=0.2, top_cv_evals=10, is_unbalance=True, random_state=None, n_jobs=-1, gpu=False, verbose=3):
-        """Initialize hgboost with user-defined parameters.
-
-        Parameters
-        ----------
-        max_eval : int, (default : 250)
-            Search space is created on the number of evaluations.
-        threshold : float, (default : 0.5)
-            Classification threshold. In case of two-class model this is 0.5
-        cv : int, optional (default : 5)
-            Cross-validation. Specifying the test size by test_size.
-        top_cv_evals : int, (default : 10)
-            Number of top best performing models that is evaluated.
-            If set to None, each iteration (max_eval) is tested.
-            If set to 0, cross validation is not performed.
-        test_size : float, (default : 0.2)
-            Percentage split for the testset based on the total dataset.
-        val_size : float, (default : 0.2)
-            Percentage split for the validationset based on the total dataset. This part is kept untouched, and used only once to determine the model performance.
-        is_unbalance : Bool, (default: True)
-            Control the balance of positive and negative weights, useful for unbalanced classes.
-            xgboost clf : sum(negative instances) / sum(positive instances)
-            catboost clf : sum(negative instances) / sum(positive instances)
-            lightgbm clf : balanced
-            False: grid search
-        random_state : int, (default : None)
-            Fix the random state for validation set and test set. Note that is not used for the crossvalidation.
-        n_jobs : int, (default : -1)
-            The number of jobs to run in parallel for fit. None means 1 unless in a joblib.parallel_backend context.
-            -1 means using all processors.
-        gpu : bool, (default : False)
-            Computing using either GPU or CPU. Note that GPU usage is not very well supported because various optimizations are performed during training/testing/crossvalidation.
-            True: Use GPU.
-            False: Use CPU.
-        verbose : int, (default : 3)
-            Print progress to screen.
-            0: None, 1: ERROR, 2: WARN, 3: INFO, 4: DEBUG, 5: TRACE
-
-        Returns
-        -------
-        None.
-
-        References
-        ----------
-        * https://github.com/hyperopt/hyperopt
-        * https://www.districtdatalabs.com/parameter-tuning-with-hyperopt
-        * https://scikit-learn.org/stable/modules/model_evaluation.html
-
-        """
+        """Initialize hgboost with user-defined parameters."""
         if (threshold is None) or (threshold <= 0): raise ValueError('[hgboost] >Error: [threshold] must be >0 and not [None]')
         if (max_eval is None) or (max_eval <= 0): max_eval=1
         if top_cv_evals is None: max_eval=0
@@ -1085,7 +1097,7 @@ class hgboost:
             fig, ax = plt.subplots(figsize=figsize)
             colors = colourmap.generate(len(cv_results), cmap=cmap)
             for i, key in enumerate(cv_results.keys()):
-                sns.regplot('y', 'y_pred', data=cv_results.get(key), ax=ax, color=colors[i, :], label=key)
+                sns.regplot(x='y', y='y_pred', data=cv_results.get(key), ax=ax, color=colors[i, :], label=key)
             ax.legend()
             ax.grid(True)
             ax.set_xlabel('True value')
@@ -1130,7 +1142,7 @@ class hgboost:
             df = pd.DataFrame(np.c_[self.y_val, y_pred], columns=['y', 'y_pred'])
 
             fig, ax = plt.subplots(figsize=figsize)
-            sns.regplot('y', 'y_pred', data=df, ax=ax, color='k', label='Validation set')
+            sns.regplot(x='y', y='y_pred', data=df, ax=ax, color='k', label='Validation set')
             ax.legend()
             ax.grid(True)
             ax.set_title(title)
@@ -1275,7 +1287,7 @@ class hgboost:
                 # Make new column
                 if i_col == 0: i_row = i_row + 1
                 # Make the plot
-                sns.regplot('tid', param, data=df_sum, ax=ax2[i_row][i_col], color=color_params[i, :])
+                sns.regplot(x='tid', y=param, data=df_sum, ax=ax2[i_row][i_col], color=color_params[i, :])
 
                 # Scatter top n values, start with 1 because the 0 is, based on the ranking, with CV.
                 ax2[i_row][i_col].scatter(df_summary['tid'].values[1:top_n], df_summary[param].values[1:top_n], s=50, color='k', marker='.', label='Top ' + str(top_n) + ' models')
@@ -1342,7 +1354,7 @@ class hgboost:
         tmpdf.reset_index(drop=True, inplace=True)
 
         # Make the plot
-        sns.regplot('tid', 'loss', data=tmpdf, ax=ax1, color='#23395d', scatter=True, fit_reg=True, label=str(tmpdf.shape[0])+' models iterations')
+        sns.regplot(x='tid', y='loss', data=tmpdf, ax=ax1, color='#23395d', scatter=True, fit_reg=True, label=str(tmpdf.shape[0])+' models iterations')
         # Plot all other evalution results
         # ax1.scatter(tmpdf['tid'].values, tmpdf['loss'].values, s=10, label=str(tmpdf.shape[0])+'models iterations')
 
